pub struct DataCatalogConfig { /* private fields */ }Expand description
Configuration for a catalog available to request-time historical data loading.
Implementations
Sourceimpl DataCatalogConfig
impl DataCatalogConfig
Sourcepub fn builder() -> DataCatalogConfigBuilder
pub fn builder() -> DataCatalogConfigBuilder
Create an instance of DataCatalogConfig using the builder syntax
Sourceimpl DataCatalogConfig
impl DataCatalogConfig
Sourcepub fn new(
path: String,
fs_protocol: Option<String>,
catalog_backend: Option<CatalogBackendType>,
) -> Self
pub fn new( path: String, fs_protocol: Option<String>, catalog_backend: Option<CatalogBackendType>, ) -> Self
Creates a new DataCatalogConfig instance.
Sourcepub fn with_storage_options(
self,
options: Option<AHashMap<String, String>>,
) -> Self
pub fn with_storage_options( self, options: Option<AHashMap<String, String>>, ) -> Self
Sets native object-store connection options.
Sourcepub fn fs_rust_storage_options(&self) -> Option<&AHashMap<String, String>>
pub fn fs_rust_storage_options(&self) -> Option<&AHashMap<String, String>>
Returns native object-store options.
Sourcepub fn create_catalog(&self) -> Result<DataCatalog>
pub fn create_catalog(&self) -> Result<DataCatalog>
Creates the configured catalog through the built-in factory registry.
Errors
Returns an error if the backend is unavailable or its connection cannot be opened.
Sourcepub fn with_name(self, name: Option<String>) -> Self
pub fn with_name(self, name: Option<String>) -> Self
Returns a copy with catalog registration name set.
Sourcepub fn with_params(self, params: Option<Params>) -> Self
pub fn with_params(self, params: Option<Params>) -> Self
Returns a copy with backend-specific catalog parameters set.
Sourcepub const fn with_read_only(self, read_only: bool) -> Self
pub const fn with_read_only(self, read_only: bool) -> Self
Returns a copy with read-only response write-back behavior set.
Sourcepub fn fs_protocol(&self) -> &str
pub fn fs_protocol(&self) -> &str
Returns the fsspec file system protocol for the data catalog.
Sourcepub const fn catalog_backend(&self) -> &CatalogBackendType
pub const fn catalog_backend(&self) -> &CatalogBackendType
Returns the catalog backend implementation to use.